{
    // array die alle mogelijke cijfers van een kaart bevat.  Naast de cijfers is er ook nog J(oker), Q(ueen), K(ing) en A(ce)
    const cardNumbers = [`2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `10`, `J`, `Q`, `K`, `A`];
    // array die alle mogelijke soorten bevat: Clubs (klaveren), Diamonds (ruiten), Hearts (harten) en Spades (schoppen)
    const cardSuits = [`C`, `D`, `H`, `S`];

    const sortCardsByNumber = (a, b) => {
        if (cardNumbers.indexOf(getCardNumber(a)) < cardNumbers.indexOf(getCardNumber(b))){
            return -1;
        }else{
            return 1;
        }
    };

    // functie die een getal aanmaakt tussen 0 en het maximum waarbij het maximum niet is inbegrepen
    // Zie: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Math/random
    const getRandomNumber = (max) => {
        return Math.floor(Math.random() * Math.floor(max));
    }

    // functie om het nummer van een kaart terug te geven
    const getCardNumber = card => card.split(`-`)[0];

    // functie om de suit van de kaart terug te geven
    const getCardSuit = card => card.split(`-`)[1];

    const pickRandomCard = () => {
        // kies een willekeurig element uit de array met nummers
        const number = cardNumbers[getRandomNumber(cardNumbers.length)];
        // kies een willekeurig element uit de array met soorten
        const suit = cardSuits[getRandomNumber(cardSuits.length)];
        // geef de combinatie terug. Dit matcht met de bestandsnaam van de afbeelding 
        return `${number}-${suit}`;
    }

    const getRandomCards = amount => {
        // maak een lege array, deze zal uiteindelijk evenveel kaarten bevatten als opgegeven in amount
        const cards = [];
        // zolang de array minder kaarten heeft dan gevraagd wordt onderstaande uitgevoerd.
        while (cards.length < amount) {
            // haal een random kaart op
            const card = pickRandomCard();
            // controleer of deze kaart al in de array zit, voeg enkel toe indien niet
            if (!cards.includes(card)) {
                cards.push(card);
            }
        }
        // geef de array met gekozen kaarten terug
        return cards.sort(sortCardsByNumber);
    };

    const showCards = pickedCards => {
        // selecteer het element waar de kaarten aan zullen toegevoegd worden
        const $table = document.querySelector(`.game-table`);
        // gebruik de combinatie van map() en join() om <li> elementen aan te maken die de juiste afbeelding bevatten
        $table.innerHTML = pickedCards.map(card => `<li><img src="assets/img/${card}.jpg" alt="card" width="130" height="199"></li>`).join(``);
    };

    
    const init = () => {
        // Selecteer 5 unieke kaarten.  
        const pickedCards = getRandomCards(5);
        // gebruik deze array om combinaties die zelden zijn (zoals royal flush) te testen
        //const pickedCards = [`5-H`, `5-D`, `5-C`, `5-S`, `6-H`]

        // Toon deze kaarten op het scherm
        showCards(pickedCards);

    };

    init();
}
